/*
 * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 *
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 2000-2001 Apple Computer, Inc.  All rights reserved.
 *
 *  DRI: Josh de Cesare
 *
 */

enum eBtMode {
  kBtModeReset = 0,
  kBtModeStopped,
  kBtModeRunning
};
typedef enum eBtMode eBtMode;

enum eBtSource {
  kBtSource0 = 0,
  kBtSource1,
  kBtSource2,
  kBtSource3,
  kBtSourceNone = -1
};
typedef enum eBtSource eBtSource;

#define kBtSourceTypeKey       ("Type")
#define kBtSourceTypeComposite ("Composite")
#define kBtSourceTypeSVideo    ("S-Video")
#define kBtSourceTunerKey      ("Tuner")

enum eBtFormat {
  kBtFormatNone = 0,
  kBtFormatAuto,
  kBtFormatNTSC_M,
  kBtFormatNTSC_J,
  kBtFormatPAL,
  kBtFormatPAL_M,
  kBtFormatPAL_N,
  kBtFormatPAL_Nc,
  kBtFormatSECAM
};
typedef enum eBtFormat eBtFormat;

struct AppleBt8xxScreenInfo {
  UInt32 baseAddress;
  UInt32 rowBytes;
  UInt32 pixelSize;
  UInt32 width;
  UInt32 height;
};
typedef struct AppleBtxxScreenInfo AppleBtxxScreenInfo;

enum eAppleBt8xxCmd {
  kAppleBt8xxCmdNone = 0,
  kAppleBt8xxCmdSetup,
  kAppleBt8xxCmdStart,
  kAppleBt8xxCmdStop,
  kAppleBt8xxCmdGetSource,
  kAppleBt8xxCmdSetSource,
  kAppleBt8xxCmdGetTuner,
  kAppleBt8xxCmdSetTuner,
  kAppleBt8xxCmdSetVideoControl,
  kAppleBt8xxCmdReadReg,
  kAppleBt8xxCmdWriteReg,
  kAppleBt8xxCmdCount
};
typedef enum eAppleBt8xxCmd eAppleBt8xxCmd;

struct AppleBt8xxCmd {
  UInt32 type;
  UInt32 data1;
  UInt32 data2;
  UInt32 data3;
  UInt32 data4;
  UInt32 data5;
  UInt32 data6;
  UInt32 data7;
};
typedef struct AppleBt8xxCmd AppleBt8xxCmd, *AppleBt8xxCmdPtr;

struct AppleBt8xxCmdSetupInfo {
  SInt16 left;
  SInt16 top;
  SInt16 right;
  SInt16 bottom;
  UInt16 width;
  UInt16 height;
};
typedef struct AppleBt8xxCmdSetupInfo AppleBt8xxCmdSetupInfo,
  *AppleBt8xxCmdSetupInfoPtr;

enum eAppleBt8xxControl {
  kAppleBt8xxControlBrightness = 0,
  kAppleBt8xxControlContrast,
  kAppleBt8xxControlSaturationU,
  kAppleBt8xxControlSaturationV,
  kAppleBt8xxControlHue
};
typedef enum eAppleBt8xxControl eAppleBt8xxControl;

#ifndef KERNEL

extern kern_return_t AppleBt8xxCmdNone(mach_port_t connect);

extern kern_return_t AppleBt8xxCmdSetup(mach_port_t connect,
					AppleBt8xxCmdSetupInfoPtr info);

extern kern_return_t AppleBt8xxCmdStart(mach_port_t connect);
extern kern_return_t AppleBt8xxCmdStop(mach_port_t connect);

extern kern_return_t AppleBt8xxCmdGetSource(mach_port_t connect,
					    SInt32 *source);
extern kern_return_t AppleBt8xxCmdSetSource(mach_port_t connect,
					    SInt32 source);

extern kern_return_t AppleBt8xxCmdGetTuner(mach_port_t connect);
extern kern_return_t AppleBt8xxCmdSetTuner(mach_port_t connect,
					   UInt32 frequency);

extern kern_return_t AppleBt8xxCmdSetVideoControl(mach_port_t connect,
						  eAppleBt8xxControl control,
						  UInt32 value);

extern kern_return_t AppleBt8xxCmdReadReg(mach_port_t connect,
					  UInt32 reg, UInt32 *data);
extern kern_return_t AppleBt8xxCmdWriteReg(mach_port_t connect,
					   UInt32 reg, UInt32 data);

#endif
