/*
 * Copyright (c) 1998-2001 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 *
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 *
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 2000 Apple Computer, Inc.  All rights reserved.
 *
 *  DRI: Josh de Cesare
 *
 */

#include <IOKit/IOKitLib.h>
#include <IOKit/iokitmig.h>

#include "AppleBt8xxCmds.h"

kern_return_t AppleBt8xxCmdNone(mach_port_t connect)
{
  kern_return_t ret;
  unsigned int  countOut;
  
  countOut = 0;
  ret = io_connect_method_scalarI_scalarO(connect, kAppleBt8xxCmdNone,
					  NULL, 0, NULL, &countOut);
  
  return ret;
}


kern_return_t AppleBt8xxCmdSetup(mach_port_t connect,
				 AppleBt8xxCmdSetupInfoPtr info)
{
  kern_return_t ret;
  unsigned int  countOut;
  
  countOut = 0;
  ret = io_connect_method_structureI_structureO(connect, kAppleBt8xxCmdSetup,
						(unsigned char *)info,
						sizeof(AppleBt8xxCmdSetupInfo),
						NULL, &countOut);
  
  return ret;
}

kern_return_t AppleBt8xxCmdStart(mach_port_t connect)
{
  kern_return_t ret;
  unsigned int  countOut;
  
  countOut = 0;
  ret = io_connect_method_scalarI_scalarO(connect, kAppleBt8xxCmdStart,
					  NULL, 0, NULL, &countOut);
  
  return ret;
}

kern_return_t AppleBt8xxCmdStop(mach_port_t connect)
{
  kern_return_t ret;
  unsigned int  countOut;
  
  countOut = 0;
  ret = io_connect_method_scalarI_scalarO(connect, kAppleBt8xxCmdStop,
					  NULL, 0, NULL, &countOut);
  
  return ret;
}


kern_return_t AppleBt8xxCmdGetSource(mach_port_t connect, SInt32 *source)
{
  kern_return_t ret;
  unsigned int  countOut;
  
  countOut = 1;
  ret = io_connect_method_scalarI_scalarO(connect, kAppleBt8xxCmdGetSource,
                                          NULL, 0,
					  (unsigned int *)source, &countOut);
  
  return ret;
}

kern_return_t AppleBt8xxCmdSetSource(mach_port_t connect, SInt32 source)
{
  kern_return_t ret;
  unsigned int  countOut;
  
  countOut = 0;
  ret = io_connect_method_scalarI_scalarO(connect, kAppleBt8xxCmdSetSource,
                                          (unsigned int *)&source, 1,
					  NULL, &countOut);
  
  return ret;
}


kern_return_t AppleBt8xxCmdSetTuner(mach_port_t connect, UInt32 frequency)
{
  kern_return_t ret;
  unsigned int  countOut;
  
  countOut = 0;
  ret = io_connect_method_scalarI_scalarO(connect, kAppleBt8xxCmdSetTuner,
                                          (unsigned int *)&frequency, 1,
                                          NULL, &countOut);
  
  return ret;
}


kern_return_t AppleBt8xxCmdSetVideoControl(mach_port_t connect,
					   eAppleBt8xxControl control,
					   UInt32 value)
{
  kern_return_t ret;
  unsigned int  countOut, dataIn[2];
  
  dataIn[0] = (UInt32)control;
  dataIn[1] = value;
  
  countOut = 0;
  ret = io_connect_method_scalarI_scalarO(connect,
					  kAppleBt8xxCmdSetVideoControl,
                                          dataIn, 2, NULL, &countOut);
  
  return ret;
}


kern_return_t AppleBt8xxCmdReadReg(mach_port_t connect,
				   UInt32 reg, UInt32 *data)
{
  kern_return_t ret;
  unsigned int  countOut;
  
  countOut = 1;
  ret = io_connect_method_scalarI_scalarO(connect, kAppleBt8xxCmdReadReg,
                                          (unsigned int *)&reg, 1,
					  (unsigned int *)data, &countOut);
  
  return ret;
}

kern_return_t AppleBt8xxCmdWriteReg(mach_port_t connect,
				    UInt32 reg, UInt32 data)
{
  kern_return_t ret;
  unsigned int  countOut, dataIn[2];
  
  dataIn[0] = reg;
  dataIn[1] = data;
  
  countOut = 0;
  ret = io_connect_method_scalarI_scalarO(connect, kAppleBt8xxCmdWriteReg,
                                          dataIn, 2, NULL, &countOut);
  
  return ret;
}
